@@ -1,17 +1,17 @@
 #####
 calED <-
-function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
-         nsim=500, weight=TRUE, trial=FALSE, plot=TRUE, TxTn=NULL, 
-         agID=NULL, Tn3BG=NULL, TnBG.ratio=NULL,
-         rseTn=NULL, FR=NULL, Tn=NULL) {
+function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp", 
+         nsim=500, weight=TRUE, trial=FALSE, plot=TRUE, agID=NULL, 
+         Tn=NULL, Tn3BG=NULL, TnBG.ratio=NULL, rseTn=NULL, FR=NULL, 
+         LnTn.curve=NULL, TxTn=NULL) {
     UseMethod("calED")
 } ###
-### 2017.04.04. 
+### 2017.05.18. 
 calED.default <-
-function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
-         nsim=500, weight=TRUE, trial=FALSE, plot=TRUE, TxTn=NULL, 
-         agID=NULL, Tn3BG=NULL, TnBG.ratio=NULL,
-         rseTn=NULL, FR=NULL, Tn=NULL) {
+function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp", 
+         nsim=500, weight=TRUE, trial=FALSE, plot=TRUE, agID=NULL, 
+         Tn=NULL, Tn3BG=NULL, TnBG.ratio=NULL, rseTn=NULL, FR=NULL, 
+         LnTn.curve=NULL, TxTn=NULL) {
     ### Stop if not.
     stopifnot(ncol(Curvedata)==3L, nrow(Curvedata)>=1L,
               length(Ltx)==2L, is.numeric(Ltx),
@@ -22,13 +22,14 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
               length(weight)==1L, is.logical(weight), 
               length(trial)==1L, is.logical(trial),
               length(plot)==1L, is.logical(plot),
-              is.null(TxTn) || is.numeric(TxTn),
               is.null(agID) || (length(agID)==3L && is.numeric(agID)),
+              is.null(Tn) || (length(Tn)==2L && is.numeric(Tn)),
               is.null(Tn3BG) || (length(Tn3BG)==1L && Tn3BG %in% c(0L,1L)),
               is.null(TnBG.ratio) || (length(TnBG.ratio)==2L && is.numeric(TnBG.ratio)),
               is.null(rseTn) || (length(rseTn)==1L && is.numeric(rseTn)),
               is.null(FR) || (length(FR)==2L && is.numeric(FR)),
-              is.null(Tn) || (length(Tn)==2L && is.numeric(Tn)))
+              is.null(LnTn.curve) || is.list(LnTn.curve),
+              is.null(TxTn) || is.numeric(TxTn))
     ###
     dose <- as.numeric(Curvedata[,1L,drop=TRUE])
     if (any(dose<0.0)) {
@@ -326,7 +327,7 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
     ###
     ###-----------------------------------------------------------------------------
     if (plot==TRUE) {
-        layout(matrix(c(1L,1L,2L,1L,1L,2L,3L,3L,3L),nrow=3L), respect=TRUE)
+        layout(matrix(c(1L,1L,2L,1L,1L,3L,4L,4L,4L),nrow=3L), respect=TRUE)
         par(mgp=c(2.5,1,0))
         ###
         if (message %in% c(0L,4L)) {
@@ -422,18 +423,46 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
         ###
         ###-------------------------------------------------------------------------------------- 
         par(mar=c(4,4,0.5,0.5)+0.1)
+        if (!is.null(LnTn.curve)) {
+            x_max <- max(max(LnTn.curve[["Ln.x"]]), max(LnTn.curve[["Tn.x"]]), na.rm=TRUE)
+            y_max <- max(max(LnTn.curve[["Ln.y"]]), max(LnTn.curve[["Tn.y"]]), na.rm=TRUE)
+            ###
+            plot(x=LnTn.curve[["Ln.x"]], y=LnTn.curve[["Ln.y"]], type="l", lwd=1.5, col="blue",
+                 main=NULL, xlim=c(0, x_max), ylim=c(0, y_max), xlab="Stimulation time (s)", 
+                 ylab="Photon counts", las=0, xaxt="n", cex.lab=1.5, cex.main=1.5, lab=c(7,7,9))
+            ###
+            if (length(LnTn.curve[["Tn.x"]])>1L) {
+                # Both Tn.x and Tn.y are not equal to NA of length 1.
+                points(x=LnTn.curve[["Tn.x"]], y=LnTn.curve[["Tn.y"]], type="l", lwd=1.5, col="red")
+            } # end if.
+            ###
+            x_axis_location <- axTicks(side=1L)
+            axis(side=1L, at=x_axis_location, labels=as.character(x_axis_location))
+            legend("topright", legend=c("Ln decay curve", "Tn decay curve"), col=c("blue","red"), 
+                   lwd=1.5, yjust=2, ncol=1L, cex=1.0, bty="n")
+        } else {
+            plot(x=1L, y=1.0, type="n", lwd=1.5,
+                 main=NULL, xlab="Stimulation time (s)", ylab="Photon counts", las=0, 
+                 xaxt="n", yaxt="n", cex.lab=1.5, cex.main=1.5, lab=c(7,7,9))
+            axis(side=1L, at=c(0.7, 1, 1.3), labels=c("x1", "x2", "x3"))
+            axis(side=2L, at=c(0.7, 1, 1.3), labels=c("y1", "y2", "y3"))
+        } # end if.
+        ###
+        ###--------------------------------------------------------------------------------------
+        par(mar=c(4,4,0.5,0.5)+0.1)
         if (!is.null(TxTn) && all(is.finite(TxTn))) {
             plot(x=seq(length(TxTn)), y=TxTn, type="p", pch=21, bg="blue", cex=2.0, 
                  main=NULL, xlab="SAR Cycle", ylab="Tx/Tn", las=0, xaxt="n", 
                  ylim=c(0, max(TxTn)*1.5), cex.lab=1.5, cex.main=1.5, lab=c(7,7,9))
             axis(side=1L, at=seq(length(TxTn)), labels=as.character(seq(length(TxTn))))
+            abline(h=1.0, lty="dashed", col="red", lwd=1.5)
         } else {
             plot(x=1L, y=1.0, type="n", pch=21, bg="blue", cex=2.0, 
-                 main=NULL, xlab="SAR Cycle", ylab="Tx/Tn", las=0, xaxt="n",
-                 cex.lab=1.5, cex.main=1.5, lab=c(7,7,9))
-            axis(side=1L, at=1.0, labels="1")
+                 main=NULL, xlab="SAR Cycle", ylab="Tx/Tn", las=0, 
+                 xaxt="n", yaxt="n", cex.lab=1.5, cex.main=1.5, lab=c(7,7,9))
+            axis(side=1L, at=c(0.7, 1, 1.3), labels=c("x1", "x2", "x3"))
+            axis(side=2L, at=c(0.7, 1, 1.3), labels=c("y1", "y2", "y3"))
         } # end if.
-        abline(h=1.0, lty="dashed", col="red", lwd=1.5)
         ###
         ###--------------------------------------------------------------------------------------
         par(mar=c(11,0.5,11,0.5)+0.1)
@@ -462,36 +491,42 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
                    "=========================",
                    "Status: OK",
                    "=========================",
+                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), 
+                         " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
+                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
+                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), 
+                         " +/- ", round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
+                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),
+                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), 
+                         " +/- ", round(FR[2L],2L), sep="") else "NULL", sep=""),
+                   "=========================",
+                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), 
+                         " +/- ", round(seRecyclingRatio1,2L), sep=""),
+                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), 
+                         " +/- ", round(seRecyclingRatio2,2L), sep=""),  
+                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), 
+                         " +/- ", round(seRecyclingRatio3,2L), sep=""),
+                   "=========================",
+                   paste("Recuperation 1: ", round(Recuperation1,2L), 
+                         " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
+                   paste("Recuperation 2: ", round(Recuperation2,2L), 
+                         " +/- ", round(seRecuperation2,2L), " (%)",sep=""),
+                   "=========================",
                    paste("Fit model: ", paste(character_model_vec, collapse="-"), sep=""),
                    paste("Pass origin: ", origin, sep=""),
                    paste("Weighted fit: ", weight, sep=""),
-                   paste("calED method: ",calED_method, sep=""),
-                   paste("MC accept-rate: ", ifelse(errMethod=="sp","NULL", round(acceptRate,2L)), " (%)", sep=""),
-                   "=========================",
-                   paste("ED: ",round(ED,2L), " +/- ",round(seED,2L)," (Gy|s)",sep=""),
-                   paste("RSE of ED: ",round(seED/abs(ED)*100.0,2L)," (%)",sep=""),
-                   paste("95% interval: [",round(ConfInt[3L],2L),", ",round(ConfInt[4L],2L),"]", sep=""), 
-                   paste("68% interval: [",round(ConfInt[1L],2L),", ",round(ConfInt[2L],2L),"]", sep=""),
-                   "=========================",
-                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), " +/- ", round(seRecyclingRatio1,2L), sep=""),
-                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), " +/- ", round(seRecyclingRatio2,2L), sep=""),  
-                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), " +/- ", round(seRecyclingRatio3,2L), sep=""),
-                   "=========================",
-                   paste("Recuperation 1: ", round(Recuperation1,2L), " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
-                   paste("Recuperation 2: ", round(Recuperation2,2L), " +/- ", round(seRecuperation2,2L), " (%)",sep=""),
-                   "=========================",
-                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
-                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),
-                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), " +/- ", 
-                         round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), " +/- ", 
-                         round(FR[2L],2L), sep="") else "NULL", sep=""),
-                   "=========================",
                    paste("Minimized value: ", round(min_obj,2L),sep=""),
                    paste("Average error in fit: ", round(avg_fit_error,2L),sep=""), 
                    paste("Reduced Chi-Square: ", round(RCS,2L),sep=""),
-                   paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep="")),                    
+                   paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep=""),
+                   "=========================",
+                   paste("calED method: ",calED_method, sep=""),
+                   paste("MC acceptance-rate: ", ifelse(errMethod=="sp", "NULL",
+                         round(acceptRate,2L)), " (%)", sep=""),
+                   paste("ED: ",round(ED,2L), " +/- ",round(seED,2L)," (Gy|s)",sep=""),
+                   paste("RSE of ED: ",round(seED/abs(ED)*100.0,2L)," (%)",sep=""),
+                   paste("95% interval: [",round(ConfInt[3L],2L),", ",round(ConfInt[4L],2L),"]", sep=""), 
+                   paste("68% interval: [",round(ConfInt[1L],2L),", ",round(ConfInt[2L],2L),"]", sep="")),                    
                    yjust=2, ncol=1L, cex=0.9, bty="n")
         } else if (message==1L) {
             ### message=1L: Growth curve fitting failed.
@@ -500,30 +535,41 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
                    "=========================",
                    "Status: model fit failed",
                    "=========================",
+                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), 
+                         " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
+                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""), 
+                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), 
+                         " +/- ", round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
+                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""), 
+                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), 
+                         " +/- ", round(FR[2L],2L), sep="") else "NULL", sep=""),
+                   "=========================",
+                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), 
+                         " +/- ", round(seRecyclingRatio1,2L), sep=""),
+                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), 
+                         " +/- ", round(seRecyclingRatio2,2L), sep=""),  
+                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), 
+                         " +/- ", round(seRecyclingRatio3,2L), sep=""),
+                   "=========================",
+                   paste("Recuperation 1: ", round(Recuperation1,2L), 
+                         " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
+                   paste("Recuperation 2: ", round(Recuperation2,2L), 
+                         " +/- ", round(seRecuperation2,2L), " (%)",sep=""),  
+                   "=========================",
                    paste("Fit model: ", paste(character_model_vec, collapse="-"), sep=""),
                    paste("Pass origin: ", origin, sep=""),
                    paste("Weighted fit: ", weight, sep=""),
-                   paste("calED method: ",calED_method, sep=""),
+                   "Minimized value: NULL",
+                   "Average error in fit: NULL", 
+                   "Reduced Chi-Square: NULL",
+                   "Figure Of Merit: NULL (%)",
                    "=========================",
+                   paste("calED method: ",calED_method, sep=""),
+                   "MC acceptance-rate: NULL (%)",
                    paste("ED: ",NA, " +/- ",NA," (Gy|s)",sep=""),
                    "RSE of ED: NA (%)",
                    "95% interval: [NA, NA]", 
-                   "68% interval: [NA, NA]", 
-                   "=========================",
-                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), " +/- ", round(seRecyclingRatio1,2L), sep=""),
-                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), " +/- ", round(seRecyclingRatio2,2L), sep=""),  
-                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), " +/- ", round(seRecyclingRatio3,2L), sep=""),
-                   "=========================",
-                   paste("Recuperation 1: ", round(Recuperation1,2L), " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
-                   paste("Recuperation 2: ", round(Recuperation2,2L), " +/- ", round(seRecuperation2,2L), " (%)",sep=""),  
-                   "=========================",
-                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
-                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),  
-                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), " +/- ", 
-                         round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), " +/- ", 
-                         round(FR[2L],2L), sep="") else "NULL", sep="")),                       
+                   "68% interval: [NA, NA]"),                      
                    yjust=2, ncol=1L, cex=0.9, bty="n")
         } else if (message==2L) {
             ### message=2L: natural signal saturated.
@@ -532,35 +578,41 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
                    "=========================",
                    "Status: Ln/Tn saturated",
                    "=========================",
+                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), 
+                         " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
+                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
+                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), 
+                         " +/- ", round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
+                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),
+                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), 
+                         " +/- ", round(FR[2L],2L), sep="") else "NULL", sep=""),
+                   "=========================",
+                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), 
+                         " +/- ", round(seRecyclingRatio1,2L), sep=""),
+                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), 
+                         " +/- ", round(seRecyclingRatio2,2L), sep=""),  
+                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), 
+                         " +/- ", round(seRecyclingRatio3,2L), sep=""),
+                   "=========================",
+                   paste("Recuperation 1: ", round(Recuperation1,2L), 
+                         " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
+                   paste("Recuperation 2: ", round(Recuperation2,2L), 
+                         " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
+                   "=========================",
                    paste("Fit model: ", paste(character_model_vec, collapse="-"), sep=""),
                    paste("Pass origin: ", origin, sep=""),
                    paste("Weighted fit: ", weight, sep=""),
-                   paste("calED method: ",calED_method, sep=""),
-                   "=========================",
-                   paste("ED: ",Inf, " +/- ",NA," (Gy|s)",sep=""),
-                   "RSE of ED: NA (%)",
-                   "95% interval: [-Inf, +Inf]", 
-                   "68% interval: [-Inf, +Inf]", 
-                   "=========================",
-                   paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), " +/- ", round(seRecyclingRatio1,2L), sep=""),
-                   paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), " +/- ", round(seRecyclingRatio2,2L), sep=""),  
-                   paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), " +/- ", round(seRecyclingRatio3,2L), sep=""),
-                   "=========================",
-                   paste("Recuperation 1: ", round(Recuperation1,2L), " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
-                   paste("Recuperation 2: ", round(Recuperation2,2L), " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
-                   "=========================", 
-                   paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
-                   paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),
-                   paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), " +/- ", 
-                         round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
-                   paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), " +/- ", 
-                         round(FR[2L],2L), sep="") else "NULL", sep=""),
-                   "=========================",
                    paste("Minimized value: ", round(min_obj,2L),sep=""),
                    paste("Average error in fit: ", round(avg_fit_error,2L),sep=""), 
                    paste("Reduced Chi-Square: ", round(RCS,2L),sep=""),
-                   paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep="")),                                 
+                   paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep=""),
+                   "=========================",
+                   paste("calED method: ",calED_method, sep=""),
+                   "MC acceptance-rate: NULL (%)",
+                   paste("ED: ",Inf, " +/- ",NA," (Gy|s)",sep=""),
+                   "RSE of ED: NA (%)",
+                   "95% interval: [-Inf, +Inf]", 
+                   "68% interval: [-Inf, +Inf]"),                                
                    yjust=2, ncol=1L, cex=0.9, bty="n")
         } else if (message==3L) {
             ### message=3L: ED calculation failed.
@@ -569,35 +621,41 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
                   "=========================",
                   "Status: ED failed (ED < -50 Gy|s)",
                   "=========================",
+                  paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), 
+                        " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
+                  paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
+                  paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), 
+                        " +/- ", round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
+                  paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""), 
+                  paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), 
+                        " +/- ", round(FR[2L],2L), sep="") else "NULL", sep=""),
+                  "=========================",
+                  paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), 
+                        " +/- ", round(seRecyclingRatio1,2L), sep=""),
+                  paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), 
+                        " +/- ", round(seRecyclingRatio2,2L), sep=""),  
+                  paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), 
+                        " +/- ", round(seRecyclingRatio3,2L), sep=""),
+                  "=========================",
+                  paste("Recuperation 1: ", round(Recuperation1,2L), 
+                        " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
+                  paste("Recuperation 2: ", round(Recuperation2,2L), 
+                        " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
+                  "=========================",
                   paste("Fit model: ", paste(character_model_vec, collapse="-"), sep=""),
                   paste("Pass origin: ", origin, sep=""),
                   paste("Weighted fit: ", weight, sep=""),
-                  paste("calED method: ",calED_method, sep=""),
-                  "=========================",
-                  paste("ED: ",NA, " +/- ",NA," (Gy|s)",sep=""),
-                  "RSE of ED: NA (%)",
-                  "95% interval: [NA, NA]", 
-                  "68% interval: [NA, NA]", 
-                  "=========================",
-                  paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), " +/- ", round(seRecyclingRatio1,2L), sep=""),
-                  paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), " +/- ", round(seRecyclingRatio2,2L), sep=""),  
-                  paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), " +/- ", round(seRecyclingRatio3,2L), sep=""),
-                  "=========================",
-                  paste("Recuperation 1: ", round(Recuperation1,2L), " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
-                  paste("Recuperation 2: ", round(Recuperation2,2L), " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
-                  "=========================",
-                  paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
-                  paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
-                  paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""), 
-                  paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), " +/- ", 
-                        round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
-                  paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), " +/- ", 
-                        round(FR[2L],2L), sep="") else "NULL", sep=""),
-                  "=========================",
                   paste("Minimized value: ", round(min_obj,2L),sep=""),
                   paste("Average error in fit: ", round(avg_fit_error,2L),sep=""), 
                   paste("Reduced Chi-Square: ", round(RCS,2L),sep=""),
-                  paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep="")),                                  
+                  paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep=""),
+                  "=========================",
+                  paste("calED method: ",calED_method, sep=""),
+                  "MC acceptance-rate: NULL (%)",
+                  paste("ED: ",NA, " +/- ",NA," (Gy|s)",sep=""),
+                  "RSE of ED: NA (%)",
+                  "95% interval: [NA, NA]", 
+                  "68% interval: [NA, NA]"),                               
                   yjust=2, ncol=1L, cex=0.9, bty="n")
         } else if (message==4L) {
             ### message=4L: ED Error calculation failed.
@@ -605,38 +663,44 @@ function(Curvedata, Ltx, model="gok", origin=FALSE, errMethod="sp",
                   legend=c(paste("ID: ", NO_Position_Grain, sep=""),
                   "=========================",
                   ifelse(errMethod=="mc",
-                  "Status: ED Error failed (MC accept-rate < 1%)",
+                  "Status: ED Error failed (MC AR < 1%)",
                   "Status: ED Error failed (infinite upper ED)"),
                   "=========================",
+                  paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), 
+                        " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
+                  paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
+                  paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), 
+                        " +/- ", round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
+                  paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""),
+                  paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), 
+                        " +/- ", round(FR[2L],2L), sep="") else "NULL", sep=""),
+                  "=========================",
+                  paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), 
+                        " +/- ", round(seRecyclingRatio1,2L), sep=""),
+                  paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), 
+                        " +/- ", round(seRecyclingRatio2,2L), sep=""),  
+                  paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), 
+                        " +/- ", round(seRecyclingRatio3,2L), sep=""),
+                  "=========================",
+                  paste("Recuperation 1: ", round(Recuperation1,2L), 
+                        " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
+                  paste("Recuperation 2: ", round(Recuperation2,2L), 
+                        " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
+                  "=========================",
                   paste("Fit model: ", paste(character_model_vec, collapse="-"), sep=""),
                   paste("Pass origin: ", origin, sep=""),
                   paste("Weighted fit: ", weight, sep=""),
-                  paste("calED method: ",calED_method, sep=""),
-                  "=========================",               
-                  paste("ED: ",round(ED,2L), " +/- ",NA," (Gy|s)",sep=""),
-                  "RSE of ED: NA (%)",
-                  "95% interval: [NA, NA]", 
-                  "68% interval: [NA, NA]", 
-                  "=========================",
-                  paste("Recycling ratio 1: ", round(RecyclingRatio1,2L), " +/- ", round(seRecyclingRatio1,2L), sep=""),
-                  paste("Recycling ratio 2: ", round(RecyclingRatio2,2L), " +/- ", round(seRecyclingRatio2,2L), sep=""),  
-                  paste("Recycling ratio 3: ", round(RecyclingRatio3,2L), " +/- ", round(seRecyclingRatio3,2L), sep=""),
-                  "=========================",
-                  paste("Recuperation 1: ", round(Recuperation1,2L), " +/- ", round(seRecuperation1,2L), " (%)", sep=""),
-                  paste("Recuperation 2: ", round(Recuperation2,2L), " +/- ", round(seRecuperation2,2L), " (%)",sep=""), 
-                  "=========================",
-                  paste("Tn: ", if(!is.null(Tn)) paste(round(Tn[1L],2L), " +/- ", round(Tn[2L],2L), sep="") else "NULL", sep=""),
-                  paste("Tn above 3 sigma BG: ", ifelse(!is.null(Tn3BG), as.logical(Tn3BG), "NULL"), sep=""),
-                  paste("RSE of Tn: ", ifelse(!is.null(rseTn), round(rseTn,2L), "NULL"), " (%)",sep=""), 
-                  paste("Ratio of Tn to BG: ", if(!is.null(TnBG.ratio)) paste(round(TnBG.ratio[1L],2L), " +/- ", 
-                        round(TnBG.ratio[2L],2L), sep="") else "NULL", sep=""),
-                  paste("Fast ratio of Tn: ", if(!is.null(FR)) paste(round(FR[1L],2L), " +/- ", 
-                        round(FR[2L],2L), sep="") else "NULL", sep=""),
-                  "=========================",
                   paste("Minimized value: ", round(min_obj,2L),sep=""),
                   paste("Average error in fit: ", round(avg_fit_error,2L),sep=""),
                   paste("Reduced Chi-Square: ", round(RCS,2L),sep=""),
-                  paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep="")),                              
+                  paste("Figure Of Merit: ", round(FOM,2L)," (%)",sep=""),
+                  "=========================", 
+                  paste("calED method: ",calED_method, sep=""),
+                  "MC acceptance-rate: <1 (%)",         
+                  paste("ED: ",round(ED,2L), " +/- ",NA," (Gy|s)",sep=""),
+                  "RSE of ED: NA (%)",
+                  "95% interval: [NA, NA]", 
+                  "68% interval: [NA, NA]"),                          
                   yjust=2, ncol=1L, cex=0.9, bty="n")
         } # end if.
         ###
